==> icsdscraper-0.0.2.tar.gz: icsdscraper-0.0.2/README.md <==
{\rtf1\ansi\ansicpg1252\cocoartf2511
\cocoatextscaling0\cocoaplatform0{\fonttbl\f0\fswiss\fcharset0 Helvetica;}
{\colortbl;\red255\green255\blue255;}
{\*\expandedcolortbl;;}
\paperw11900\paperh16840\margl1440\margr1440\vieww10800\viewh8400\viewkind0
\pard\tx566\tx1133\tx1700\tx2267\tx2834\tx3401\tx3968\tx4535\tx5102\tx5669\tx6236\tx6803\pardirnatural\partightenfactor0

\f0\fs24 \cf0 Scrapping professors and courses from [ICSD website](http://www.icsd.aegean.gr/icsd/)\
\
Original idea by [Yannis Alexiou](https://github.com/yannisalexiou). Check his implementation in NodeJS [here](https://www.npmjs.com/package/icsd-scraper)\
\
Install package:\
````\
pip install icsd-scraper\
````\
Import main library:\
````\
import PapaScrap\
````\
Retrieve object like so:\
````\
professors = PapaScrap.getProfessors()\
\
for obj in professors:\
    print obj.name\
````\
## Functions \
### getProfessors\
Returns all professors as an array of objects with the below details:\
\
**name, academicRank, link, office, tel, email, website, image**\
\
### getBasicCourses\
Returns all courses as an array of objects with the below details:\
\
**title, code, semester, ects, theoryHours, labHours, professor, link**\
\
### getAdvancedCourses\
Returns all courses as an array of objects with the below details:\
\
**contentOutline, learningOutcomes, prerequisites, basicTextbooks, additionalReferences, teachingMethod, grandingMethod, languageOfInstruction, modeOfDelivery**\
\
**\uc0\u921 mportant:** `getAdvancedCourses` doesn't always work properly due to lack of consistency of ICSD site. So it's better to use the `getBasicCourses` to retrieve basic course information.}

==> icsdscraper-0.0.12.tar.gz: icsdscraper-0.0.12/README.md <==
{\rtf1\ansi\ansicpg1252\cocoartf2511
\cocoatextscaling0\cocoaplatform0{\fonttbl\f0\fswiss\fcharset0 Helvetica;}
{\colortbl;\red255\green255\blue255;}
{\*\expandedcolortbl;;}
\paperw11900\paperh16840\margl1440\margr1440\vieww10800\viewh8400\viewkind0
\pard\tx566\tx1133\tx1700\tx2267\tx2834\tx3401\tx3968\tx4535\tx5102\tx5669\tx6236\tx6803\pardirnatural\partightenfactor0

\f0\fs24 \cf0 \
Scrapping professors and courses from [ICSD website](http://www.icsd.aegean.gr/icsd/)\
\
Original idea by [Yannis Alexiou](https://github.com/yannisalexiou). Check his implementation in NodeJS [here](https://www.npmjs.com/package/icsd-scraper)\
\
Install package:\
- pip install icsd-scraper\
Import main library:\
- import PapaScrap\
\
## Functions \
### getProfessors\
Returns all professors as an array of objects with the below details:\
\
**name, academicRank, link, office, tel, email, website, image**\
\
### getBasicCourses\
Returns all courses as an array of objects with the below details:\
\
**title, code, semester, ects, theoryHours, labHours, professor, link**\
\
### getAdvancedCourses\
Returns all courses as an array of objects with the below details:\
\
**contentOutline, learningOutcomes, prerequisites, basicTextbooks, additionalReferences, teachingMethod, grandingMethod, languageOfInstruction, modeOfDelivery**\
\
**\uc0\u921 mportant:** `getAdvancedCourses` doesn't always work properly due to lack of consistency of ICSD site. So it's better to use the `getBasicCourses` to retrieve basic course information.}
